==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/AuthenticationRequest.hpp <==
#ifndef _COM_SUN_STAR_UCB_AUTHENTICATIONREQUEST_HPP_
#define _COM_SUN_STAR_UCB_AUTHENTICATIONREQUEST_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_AUTHENTICATIONREQUEST_HDL_
#include "com/sun/star/ucb/AuthenticationRequest.hdl"
#endif

#ifndef _COM_SUN_STAR_TASK_CLASSIFIEDINTERACTIONREQUEST_HPP_
#include "com/sun/star/task/ClassifiedInteractionRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline AuthenticationRequest::AuthenticationRequest() SAL_THROW( () )
    : ::com::sun::star::task::ClassifiedInteractionRequest()
    , ServerName()
    , Diagnostic()
    , HasRealm(false)
    , Realm()
    , HasUserName(false)
    , UserName()
    , HasPassword(false)
    , Password()
    , HasAccount(false)
    , Account()
{ }

inline AuthenticationRequest::AuthenticationRequest(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::task::InteractionClassification& Classification_, const ::rtl::OUString& ServerName_, const ::rtl::OUString& Diagnostic_, const ::sal_Bool& HasRealm_, const ::rtl::OUString& Realm_, const ::sal_Bool& HasUserName_, const ::rtl::OUString& UserName_, const ::sal_Bool& HasPassword_, const ::rtl::OUString& Password_, const ::sal_Bool& HasAccount_, const ::rtl::OUString& Account_) SAL_THROW( () )
    : ::com::sun::star::task::ClassifiedInteractionRequest(Message_, Context_, Classification_)
    , ServerName(ServerName_)
    , Diagnostic(Diagnostic_)
    , HasRealm(HasRealm_)
    , Realm(Realm_)
    , HasUserName(HasUserName_)
    , UserName(UserName_)
    , HasPassword(HasPassword_)
    , Password(Password_)
    , HasAccount(HasAccount_)
    , Account(Account_)
{ }

AuthenticationRequest::AuthenticationRequest(AuthenticationRequest const & the_other): ::com::sun::star::task::ClassifiedInteractionRequest(the_other), ServerName(the_other.ServerName), Diagnostic(the_other.Diagnostic), HasRealm(the_other.HasRealm), Realm(the_other.Realm), HasUserName(the_other.HasUserName), UserName(the_other.UserName), HasPassword(the_other.HasPassword), Password(the_other.Password), HasAccount(the_other.HasAccount), Account(the_other.Account) {}

AuthenticationRequest::~AuthenticationRequest() {}

AuthenticationRequest & AuthenticationRequest::operator =(AuthenticationRequest const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::task::ClassifiedInteractionRequest::operator =(the_other);
    ServerName = the_other.ServerName;
    Diagnostic = the_other.Diagnostic;
    HasRealm = the_other.HasRealm;
    Realm = the_other.Realm;
    HasUserName = the_other.HasUserName;
    UserName = the_other.UserName;
    HasPassword = the_other.HasPassword;
    Password = the_other.Password;
    HasAccount = the_other.HasAccount;
    Account = the_other.Account;
    return *this;
}

} } } }

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::ucb::AuthenticationRequest* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.ucb.AuthenticationRequest" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

#endif // _COM_SUN_STAR_UCB_AUTHENTICATIONREQUEST_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/AuthenticationRequest.hpp <==
#ifndef _COM_SUN_STAR_UCB_AUTHENTICATIONREQUEST_HPP_
#define _COM_SUN_STAR_UCB_AUTHENTICATIONREQUEST_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_AUTHENTICATIONREQUEST_HDL_
#include "com/sun/star/ucb/AuthenticationRequest.hdl"
#endif

#ifndef _COM_SUN_STAR_TASK_CLASSIFIEDINTERACTIONREQUEST_HPP_
#include "com/sun/star/task/ClassifiedInteractionRequest.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline AuthenticationRequest::AuthenticationRequest() SAL_THROW( () )
    : ::com::sun::star::task::ClassifiedInteractionRequest()
    , ServerName()
    , Diagnostic()
    , HasRealm(false)
    , Realm()
    , HasUserName(false)
    , UserName()
    , HasPassword(false)
    , Password()
    , HasAccount(false)
    , Account()
{ }

inline AuthenticationRequest::AuthenticationRequest(const ::rtl::OUString& Message_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context_, const ::com::sun::star::task::InteractionClassification& Classification_, const ::rtl::OUString& ServerName_, const ::rtl::OUString& Diagnostic_, const ::sal_Bool& HasRealm_, const ::rtl::OUString& Realm_, const ::sal_Bool& HasUserName_, const ::rtl::OUString& UserName_, const ::sal_Bool& HasPassword_, const ::rtl::OUString& Password_, const ::sal_Bool& HasAccount_, const ::rtl::OUString& Account_) SAL_THROW( () )
    : ::com::sun::star::task::ClassifiedInteractionRequest(Message_, Context_, Classification_)
    , ServerName(ServerName_)
    , Diagnostic(Diagnostic_)
    , HasRealm(HasRealm_)
    , Realm(Realm_)
    , HasUserName(HasUserName_)
    , UserName(UserName_)
    , HasPassword(HasPassword_)
    , Password(Password_)
    , HasAccount(HasAccount_)
    , Account(Account_)
{ }

AuthenticationRequest::AuthenticationRequest(AuthenticationRequest const & the_other): ::com::sun::star::task::ClassifiedInteractionRequest(the_other), ServerName(the_other.ServerName), Diagnostic(the_other.Diagnostic), HasRealm(the_other.HasRealm), Realm(the_other.Realm), HasUserName(the_other.HasUserName), UserName(the_other.UserName), HasPassword(the_other.HasPassword), Password(the_other.Password), HasAccount(the_other.HasAccount), Account(the_other.Account) {}

AuthenticationRequest::~AuthenticationRequest() {}

AuthenticationRequest & AuthenticationRequest::operator =(AuthenticationRequest const & the_other) {
    //TODO: Just like its implicitly-defined counterpart, this function definition is not exception-safe
    ::com::sun::star::task::ClassifiedInteractionRequest::operator =(the_other);
    ServerName = the_other.ServerName;
    Diagnostic = the_other.Diagnostic;
    HasRealm = the_other.HasRealm;
    Realm = the_other.Realm;
    HasUserName = the_other.HasUserName;
    UserName = the_other.UserName;
    HasPassword = the_other.HasPassword;
    Password = the_other.Password;
    HasAccount = the_other.HasAccount;
    Account = the_other.Account;
    return *this;
}

} } } }

namespace com { namespace sun { namespace star { namespace ucb {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::ucb::AuthenticationRequest const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_EXCEPTION, "com.sun.star.ucb.AuthenticationRequest" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::ucb::AuthenticationRequest const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::ucb::AuthenticationRequest >::get();
}

#endif // _COM_SUN_STAR_UCB_AUTHENTICATIONREQUEST_HPP_
